pub struct SendWithIdRequestModel {Show 16 fields
pub type: Option<SendType>,
pub auth_type: Option<AuthType>,
pub file_length: Option<i64>,
pub name: Option<String>,
pub notes: Option<String>,
pub key: String,
pub max_access_count: Option<i32>,
pub expiration_date: Option<String>,
pub deletion_date: String,
pub file: Option<Box<SendFileModel>>,
pub text: Option<Box<SendTextModel>>,
pub password: Option<String>,
pub emails: Option<String>,
pub disabled: bool,
pub hide_email: Option<bool>,
pub id: Uuid,
}Expand description
SendWithIdRequestModel : A send request issued by a Bitwarden client
Fields
type: Option<SendType>auth_type: Option<AuthType>file_length: Option<i64>Estimated length of the file accompanying the send. null when Bit.Api.Tools.Models.Request.SendRequestModel.Type is Bit.Core.Tools.Enums.SendType.Text.
name: Option<String>Label for the send.
notes: Option<String>Notes for the send. This is only visible to the owner of the send.
key: StringA base64-encoded byte array containing the Send’s encryption key. This key is also provided to send recipients in the Send’s URL.
max_access_count: Option<i32>The maximum number of times a send can be accessed before it expires. When this value is null, there is no limit.
expiration_date: Option<String>The date after which a send cannot be accessed. When this value is null, there is no expiration date.
deletion_date: StringThe date after which a send may be automatically deleted from the server. The server enforces a maximum of 31 days from creation. A background job deletes sends once this date has passed.
file: Option<Box<SendFileModel>>text: Option<Box<SendTextModel>>password: Option<String>Base64-encoded byte array of a password hash that grants access to the send. Mutually exclusive with Bit.Api.Tools.Models.Request.SendRequestModel.Emails.
emails: Option<String>Comma-separated list of emails that may access the send using OTP authentication. Mutually exclusive with Bit.Api.Tools.Models.Request.SendRequestModel.Password.
disabled: boolWhen true, send access is disabled. Defaults to false.
hide_email: Option<bool>When true send access hides the user’s email address and displays a confirmation message instead. Defaults to false.
id: UuidIdentifies the send. When this is null, the client is requesting a new send.
Implementations